#!/usr/bin/env python3

import netifaces
import json
def read_pppoe_data(file_path):
    try:
        with open(file_path, 'r') as file:
            lines = file.readlines()
    except FileNotFoundError:
        print(f"拨号数据文件 '{file_path}' 未找到")
        return []

    pppoe_data = []
    ppp_interfaces = [interface for interface in netifaces.interfaces() if interface.startswith('ppp')]
    if not ppp_interfaces:
        print("未找到 PPP 接口")
        return []

    for line, ppp_interface in zip(lines, ppp_interfaces):
        # 只获取每行的前四个字段
        vlan_id, account, password, bind_adapter_name, *_ = line.strip().split()
        ip = netifaces.ifaddresses(ppp_interface)[netifaces.AF_INET][0]['addr']
        dial_data = {
            "account": account,
            "password": password,
            "vlan_id": vlan_id,
            "bind_adapter_name": bind_adapter_name,
            "ip": ip,
            "is_manage": 0,
            "is_nat1": 1,
            "adapter_name": ppp_interface,
            "ipv6": ""
        }
        pppoe_data.append(dial_data)

    return pppoe_data

def main():
    file_path = '/opt/pppoe/pppoe_user.txt'
    pppoe_data = read_pppoe_data(file_path)
    print(json.dumps({"dial": pppoe_data}, indent=4))

if __name__ == "__main__":
    main()
